# Purine motif code

The code in this repository is designed to work with purine receptor protein sequences and the genomes in which they are encoded.

* [System Requirements](https://github.com/ToshkaDev/Purine-pyrimidine_motif/tree/main/Code#system-requirements)
* [Installation](https://github.com/ToshkaDev/Purine-pyrimidine_motif/tree/main/Code#installation)
* [Description of the Code Functionality](https://github.com/ToshkaDev/Purine-pyrimidine_motif/tree/main/Code#description-of-the-code-functionality)
* [Examples](https://github.com/ToshkaDev/Purine-pyrimidine_motif/tree/main/Code#examples)

# System Requirements

## Hardware requirements

The scripts require only a standard computer with enough RAM to support the in-memory operations.

## Software requirements

Python 3.6+

### OS Requirements

The scripts have been tested on the following systems:

    Linux: Ubuntu 20.04, Mint 20.2

### Python Dependencies
* Biopython
* NumPy

# Installation

git clone https://github.com/ToshkaDev/Purine-pyrimidine_motif.git

cd Code

The repository will be downloaded within a few seconds. The scripts in the folder are ready to be executed.

# Description of the Code Functionality

The set of scripts is designed to perform several types of analysis: motif analysis, obtaining protein domain information for a list of proteins, retrieving biosample information for the target genomes, assigning GTDB taxonomy to respective organisms, and generating slurm scripts to run AlphaFold on a high performance cluster. All scripts take input files from the **Input** folder and output results to the **Output** folder. The **Output** folder currently contains output files generated by running the example snippets provided in Examples section below.

```countPurineMotifInGenomes.py```: scans the provided alignment to output purine motif variants and protein sequences containing the motif

```processTrendJson.py```: analyzes a JSON file obtained from [TREND](http://trend.evobionet.com/domains) containing protein domain information to output protein domain compositions, domain counts, and domain composition to organism mappings for each protein in the provided file

```processTrendJson.py``` parameters: 

```-i``` - input file with protein domains information in json format; 

```-o``` - output file with protein domain to protein mappings; 

```-a``` - output file with protein domain compositions and their counts; 

```-g``` - output file with protein domain composition to organism mappings.

```getBioSample.py```: retrieves biosample information from NCBI for each genome in the provided genome list

```getFullTaxonomy_and_append.py```: retrieves GTDB taxonomy for each organism in the provided organism list. Requires GTDB taxonomy file in the same folder as the script with the following fields: accession, gtdb_taxonomy, ncbi_organism_name, ncbi_taxonomy. The GTDB taxonomy file is currently specified in the script: ```GTDB_METADATA_FILE_PREPARED = "./Input/ar122_bac120_metadata_r202_GBRSdeleted.tsv"```. Organism names column in the input file is specified by ```-c``` parameter.

```getFullTaxonomy_and_append.py -h``` will show all used parameters and their descriptions. 

```prepare_slurm_scripts_for_AF.sh```: creates slurm scripts based on the provided protein files taking protein names from the file names. The scripts takes protein names from the **Input/aa_sequences_for_AF** folder and outputs results to the **Output/slurm_for_AF** folder.

# Examples

1) Scan the alignment and output variants of a given motif and protein sequences with the motif:

```
./countPurineMotifInGenomes.py list ./Output/purine_receptors_aln_linsi_ed_list.txt ./Input/purine_receptors_aln_linsi_ed.fa
./countPurineMotifInGenomes.py fasta ./Output/purine_receptors_aln_linsi_ed_proteins.fa ./Input/purine_receptors_aln_linsi_ed.fa
```

3) Output protein domain information for each protein:

```
./processTrendJson.py -i ./Input/purine_receptors_domains_TREND.json -o ./Output/purine_receptors_domains_TREND_architectures.txt -a ./Output/purine_receptors_domains_TREND_architecture_counts.txt -g ./Output/purine_receptors_domains_TREND_architecture_organisms.txt 
```

3) Obtain biosample information for a list of genomes:

```
./getBioSample.py ./Input/genome_ids_test.txt > ./Output/genome_ids_test_BiosampleInfo.txt
```

4) Get GTDB taxonomy for a list of organisms:

```
unzip ./Input/ar122_bac120_metadata_r202_GBRSdeleted.tsv.zip -d ./Input

./getFullTaxonomy_and_append.py -c 1 -d '\t' -i ./Input/protein_ids_andOrgNames.txt -s GTDB  -o ./Output/protein_ids_andOrgNames_fullTaxonomy.txt
```

5) Create slurm scripts to run on HPC:

```
./prepare_slurm_scripts_for_AF.sh
```
