#!/usr/bin/python3
#Author: Vadim M. Gumerov

from Bio import SeqIO
import sys

'''The script can processes several alignments and merge the results. 
   It reports a given motif variants and outputs (if an option is chosen) all proteins with the motif in fasta format:
   Output motif variants command:                          script list input-file output-file
   Output protins with the motif in fasta format command:  this-script fasta input-file output-file
   output-file at the end since multiple alignments can be provided.
'''

MODE = sys.argv[1]
OUPTU_FILE = sys.argv[2]
#Input file: 
INPUT_FILE1 = sys.argv[3]
#More input files with alignment can be added to the list
INPUT_FILES = [INPUT_FILE1]

#Options for MODE:
# 'list' -  output motif variuants
# 'fasta' - extract proteins that have the motif in the specified positions in 'fasta' format.

#Specify as needed:
POS1_AROMATIC = set(["Y","F"])
POS2_POSITIVE = set(["R", "K", "H"])
POS3_AROMATIC = set(["F","W"])
POS4_AROMATIC = set(["Y","F"])
POS5_POLAR_NEGATIVE = set(["D", "N"])

#zero-based
#Final in the edited alignment (specify as needed):
IF0_POS1_AROM = 112
IF0_POS2_POSITIVE = 125
IF0_POS3_AROMATIC = 138
IF0_POS4_AROMATIC = 174
IF0_POS5_POLAR_NEGATIVE = 176

#Positions coordinates
#Additional lists of positions corresponding to the alignments can be added
POSITIONS = [[IF0_POS1_AROM, IF0_POS2_POSITIVE, IF0_POS3_AROMATIC, IF0_POS4_AROMATIC, IF0_POS5_POLAR_NEGATIVE]]

def process():
	with open(OUPTU_FILE, "w") as outputFile:
		for ind in range(len(POSITIONS)):
			with open(INPUT_FILES[ind], "r") as inputFile:
				if MODE == "list":
					for record in SeqIO.parse(inputFile, "fasta"):
						protSequnce = str(record.seq)
						if protSequnce[POSITIONS[ind][0]] in POS1_AROMATIC and protSequnce[POSITIONS[ind][1]] in POS2_POSITIVE and protSequnce[POSITIONS[ind][2]] in POS3_AROMATIC \
							and protSequnce[POSITIONS[ind][3]] in POS4_AROMATIC and protSequnce[POSITIONS[ind][4]] in POS5_POLAR_NEGATIVE:
							motif = "".join([protSequnce[POSITIONS[ind][0]], "...", protSequnce[POSITIONS[ind][1]], "...", protSequnce[POSITIONS[ind][2]], "...", protSequnce[POSITIONS[ind][3]], "...", protSequnce[POSITIONS[ind][4]]])
							outputFile.write(record.description + "\t" + motif + "\n")
							
				elif MODE == "fasta":
					for record in SeqIO.parse(inputFile, "fasta"):
						protSequnce = str(record.seq)
						if protSequnce[POSITIONS[ind][0]] in POS1_AROMATIC and protSequnce[POSITIONS[ind][1]] in POS2_POSITIVE and protSequnce[POSITIONS[ind][2]] in POS3_AROMATIC \
							and protSequnce[POSITIONS[ind][3]] in POS4_AROMATIC and protSequnce[POSITIONS[ind][4]] in POS5_POLAR_NEGATIVE:					
							outputFile.write(">" + record.description + "\n")	
							outputFile.write(protSequnce + "\n")	
					
process()
