#!/usr/bin/python3

from Bio import Entrez
import json


#Increase query limit to 10/s & get warnings
Entrez.email = "***"
#Get one from https://www.ncbi.nlm.nih.gov/account/settings/ page
#Entrez.api_key=""

term="GCF_003627775.1 "
#Finds the ids associated with the assembly
def get_ids(term):
    ids = []
    handle = Entrez.esearch(db="assembly", term=term)
    record = Entrez.read(handle)
    ids.append(record["IdList"])
    return ids

#Fetch raw output
def get_raw_assembly_summary(id):
    handle = Entrez.esummary(db="assembly",id=id,report="full")
    record = Entrez.read(handle)
    #Return individual fields
    #XML output: https://eutils.ncbi.nlm.nih.gov/entrez/eutils/esummary.fcgi?db=assembly&id=79781&report=%22full%22
    #return(record['DocumentSummarySet']['DocumentSummary'][0]['AssemblyName']) #This will return the Assembly name
    return(record)

#JSON formatted output
def get_assembly_summary_json(id):
    handle = Entrez.esummary(db="assembly",id=id,report="full")
    record = Entrez.read(handle)
    #Convert raw output to json
    return(json.dumps(record, sort_keys=True,indent=4, separators=(',', ': ')))

def get_raw_biosample(id):
    handle = Entrez.esummary(db="biosample",id=id,report="full")
    return (Entrez.read(handle))

def get_biosample_json(id):
    handle = Entrez.esummary(db="biosample",id=id,report="full")
    record = Entrez.read(handle)
    return(json.dumps(record, sort_keys=True,indent=4, separators=(',', ': ')))

#Test
for id in get_ids(term):
    print (id)
    # #print(get_raw_assembly_summary(id)) #For raw output
    # biosample_id = get_raw_assembly_summary(id)["DocumentSummarySet"]["DocumentSummary"][0]["BioSampleId"]
    # print (get_biosample_json(biosample_id))
    print((get_raw_assembly_summary(id)["DocumentSummarySet"]["DocumentSummary"][0]["Organism"]))

# biosample_id = get_raw_assembly_summary("GCF_003627775.1")["DocumentSummarySet"]["DocumentSummary"][0]["BioSampleId"]
# print (get_biosample_json(biosample_id))
