#!/usr/bin/python3
#Author: Vadim M. Gumerov

from collections import OrderedDict
from Bio import Entrez
import json
import sys
import time
from html.parser import HTMLParser
#(python 2.7)
#from HTMLParser import HTMLParser

import getAssemblyBiosample

dataHeader = "GenomeAssembly\tBioSampleId\tTitle\tIsolation_Source\tIsolation_Site\tEnvironment\tGeoLocation\tOrganism\tSubmission"   
dictOfDataSample = OrderedDict([("GenomeAssembly", "NA"), ("BioSample", "NA"), ("Title", "NA"), ("Isolation_Source", "NA"), ("Isolation_Site", "NA"), ("Environment", "NA"), ("GeoLocation", "NA"), ("Organism", "NA"), ("Submission", "NA")])
dictOfData = dictOfDataSample.copy()

def processLine(line):
    time.sleep(0.333333334)
    assemblyId = line.strip()
    for eachId in getAssemblyBiosample.get_ids(assemblyId):
        biosample_id = getAssemblyBiosample.get_raw_assembly_summary(eachId)["DocumentSummarySet"]["DocumentSummary"][0]["BioSampleId"]
        biosampleSummary = getAssemblyBiosample.get_raw_biosample(biosample_id)
        sampleData = biosampleSummary["DocumentSummarySet"]["DocumentSummary"][0]["SampleData"]

        global dictOfData
        dictOfData = dictOfDataSample.copy()
        dictOfData["GenomeAssembly"] = assemblyId
        parser = MyHTMLParser()
        parser.feed(sampleData)
        printData()

def printData():
    dataString = ""
    for key, val in list(dictOfData.items()):
        dataString = dataString + val + "\t"
    print((dataString.strip()))

class MyHTMLParser(HTMLParser):
    def __init__(self):
        super(MyHTMLParser, self).__init__()
        self.title = False
        self.isolSource = False
        self.geoLoc = False
        self.bioSample = False
        self.submission = False
        self.organismname = False
        self.isolation_site = False
        self.environment = False

    def handle_starttag(self, tag, attrs):
        if tag == "title":
            self.title = True
        elif tag == "name":
            self.submission = True
        elif tag == "organismname":
            self.organismname = True
        elif tag == "id":
            for attr in attrs:
                if attr[1] == "BioSample":
                    self.bioSample = True
        elif tag == "attribute":
            for attr in attrs:
                if attr[1] == "isolation source":
                    self.isolSource = True
                if attr[1] == "Isolation Site":
                    self.isolation_site = True
                if attr[1] == "environment":
                    self.environment = True
                elif attr[1] == "geographic location":
                    self.geoLoc = True

    def handle_data(self, data):
        if self.bioSample:
            dictOfData["BioSample"] = data
            self.bioSample = False
        elif self.title:
            dictOfData["Title"] = data
            self.title = False
        elif self.submission:
            dictOfData["Submission"] = data
            self.submission = False
        elif self.isolSource:
            dictOfData["Isolation_Source"] = data
            self.isolSource = False
        elif self.isolSource:
            dictOfData["Isolation_Site"] = data
            self.isolSource = False
        elif self.isolSource:
            dictOfData["Environment"] = data
            self.isolSource = False
        elif self.geoLoc:
            dictOfData["GeoLocation"] = data
            self.geoLoc = False
        elif self.organismname:
            dictOfData["Organism"] = data
            self.organismname = False
def main():
    with open (sys.argv[1], "r") as inputFile:
        print (dataHeader)
        for line in inputFile:
            try:
                processLine(line)
            finally:
                continue

main()
