#!/bin/bash
#Author: Vadim M. Gumerov

#The script creates slurm scripts based on the provided protein files taking protein names from the file names. 

#I am outputting all the commands to create a slurm shell script for each protein in the folder. Then using the sed command I prepare an alphafold command substituting generic X and Y with corresponding file names

counter=0
for efile in ./Input/aa_sequences_for_AF/*.fa; do
    ((counter++))
    efilel=${efile##*/}


cat <<EOF > ./Output/slurm_for_AF/${efilel%.*}.sh
#!/bin/bash

#SBATCH --job-name=alphafold_target${counter}
#SBATCH --time=2-00:00:00
#SBATCH	--mem=10gb
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=8
#SBATCH --mail-type=ALL
#SBATCH --mail-user=gumerov.1@osu.edu

module reset
module load alphafold

cd \$SLURM_SUBMIT_DIR

#https://github.com/deepmind/alphafold
#Model monomer
EOF
    sed -e 's|\./X|'"${efile}"'|' -e 's|\./Y|'"${efile%.*}_output"'|' <(echo "run_alphafold.sh --model_preset=monomer --db_preset=reduced_dbs --max_template_date=2023-12-31 --use_gpu_relax=False --fasta_paths=./X  --output_dir=./Y") >> ./Output/slurm_for_AF/${efilel%.*}.sh
    
done
